import {
  select, 
  csv,
  scaleLinear,
  max, 
  scaleBand, 
  axisLeft,
  axisBottom
	} from 'd3';

// ===============  DATAVIZ  ==========

const svg = select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');


const render = data => {
  
  const xValue = d => d.value;
  const yValue = d => d.key;
  
 	const margin = {top: 50, right: 200, bottom: 50, left: 200}; 
	const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1);
  
  const yAxis = axisLeft(yScale);
  
  
  //console.log(xScale.range());
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  yAxis(g.append('g'));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0,${innerHeight})`);
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('width', d => xScale(xValue(d)))
  		.attr('height', yScale.bandwidth());

};





















	// ====== DATA INPUT =============


csv("data.csv").then(function(data) {
   
  	data.forEach(function(d) {
    d.Ages = +d.Ages;
    d["User ID"] = +d["User ID"];
    d["Year of Birth"] = +d["Year of Birth"];
  }); 
  //console.log(data[10]);
  
  // ============== NESTING / SLICERS =================== 
  
  var nestByGender = d3.nest()
  .key(function(d) { 
    return d.Gender; })
  .rollup(function(leaves) { return leaves.length; })
  .entries(data);
     //console.log(nestByGender);
  		render(nestByGender);
  
  
  var nestByRegion = d3.nest()
  .key(function(d) { 
    return d.Region; })
  .rollup(function(leaves) { return leaves.length; })
  .entries(data);
     //console.log(nestByRegion);
    //render(nestByRegion); 
  
  var nestByGeneration = d3.nest()
  .key(function(d) { 
    return d.Generation; })
  .rollup(function(leaves) { return leaves.length; })
  .entries(data);
     //console.log(nestByGeneration);
  		// render(nestByGeneration);
  
  var nestByAges = d3.nest()
  .key(function(d) { 
    return d.Ages; })
  .rollup(function(leaves) { return leaves.length; })
  .entries(data);
    // console.log(nestByAges);
 		 //render(nestByAges);
  
});
